<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="src/AboutView.cpp" line="21"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>Zunaj brskalnika je življenje!</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="22"/>
        <source>Version %1</source>
        <translation>Različica %1</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="26"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 je Prosta Programska Oprema, a njen razvoj zahteva dragocen čas.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="27"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Darujte prosim&lt;/a&gt; za podporo stalnemu razvoju %2.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="31"/>
        <source>You may want to try my other apps as well:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="34"/>
        <source>%1, a YouTube music player</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="38"/>
        <source>%1, a music player</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="44"/>
        <source>Translate %1 to your native language using %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="49"/>
        <source>Icon designed by %1.</source>
        <translation>Ikone je izrisal %1.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="53"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Izdano na podlagi licence &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="65"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="src/AboutView.h" line="25"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="src/AboutView.h" line="27"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Kar ste vedno želeli vedeti o %1 a si niste nikoli upali vprašati</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="56"/>
        <source>Clear</source>
        <translation>Počisti</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <location filename="local/src/demostartupview.cpp" line="35"/>
        <source>Please license %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="39"/>
        <source>This demo has expired.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="41"/>
        <source>The full version allows you to download videos longer than %1 minutes and to watch videos without interruptions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="43"/>
        <source>This demo will expire in %1 days.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="45"/>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="57"/>
        <source>Use Demo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="65"/>
        <source>Get the full version</source>
        <translation>Pridobi celotno različico</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="src/downloaditem.cpp" line="308"/>
        <source>bytes</source>
        <translation>byteov</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="311"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="314"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="330"/>
        <source>bytes/sec</source>
        <translation>byteov/sek</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="333"/>
        <source>KB/sec</source>
        <translation>KB/sek</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="336"/>
        <source>MB/sec</source>
        <translation>MB/sek</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="342"/>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="345"/>
        <source>minutes</source>
        <translation>minut</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="348"/>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 ostaja</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="src/downloadmanager.cpp" line="47"/>
        <source>This is just the demo version of %1.</source>
        <translation>To je samo preizkusna različica programa %1.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="49"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Prenese lahko samo posnetke krajše od %1 minut, da lahko preverite delvanje funkcije prenosa.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="55"/>
        <source>Continue</source>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="56"/>
        <source>Get the full version</source>
        <translation>Pridobi popolno različico</translation>
    </message>
    <message numerus="yes">
        <location filename="src/downloadmanager.cpp" line="137"/>
        <source>%n Download(s)</source>
        <translation><numerusform>%n Prenos</numerusform><numerusform>%n Prenosa</numerusform><numerusform>%n Prenosi</numerusform><numerusform>%n Prenosov</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="src/downloadsettings.cpp" line="14"/>
        <source>Change location...</source>
        <translation>Sprememba mesta ...</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="38"/>
        <source>Choose the download location</source>
        <translation>Izberite mesto prenosa</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="49"/>
        <source>Download location changed.</source>
        <translation>Spremenili ste mesto prenosa.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="51"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Trenutni prenosi bodo še vedno šli v prejšnje mesto.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="63"/>
        <source>Downloading to: %1</source>
        <translation>Prenos v: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="src/downloadview.cpp" line="18"/>
        <location filename="src/downloadview.h" line="22"/>
        <source>Downloads</source>
        <translation>Prenosi</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="src/globalshortcuts.cpp" line="16"/>
        <source>Play</source>
        <translation>Predvajaj</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="17"/>
        <source>Pause</source>
        <translation>Pavza</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="18"/>
        <source>Play/Pause</source>
        <translation>Predvajaj/Pavza</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="19"/>
        <source>Stop</source>
        <translation>Ustavi</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="20"/>
        <source>Stop playing after current track</source>
        <translation>Ustavi predvajanje po trenutnem posnetku</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="21"/>
        <source>Next track</source>
        <translation>Naslednji posnetek</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="22"/>
        <source>Previous track</source>
        <translation>Prejšnji posnetek</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="23"/>
        <source>Increase volume</source>
        <translation>Povečaj glasnost</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="24"/>
        <source>Decrease volume</source>
        <translation>Zmanjšaj glasnost</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="25"/>
        <source>Mute</source>
        <translation>Nemo</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="26"/>
        <source>Seek forward</source>
        <translation>Išči naprej</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="27"/>
        <source>Seek backward</source>
        <translation>Išči nazaj</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="src/ListModel.cpp" line="51"/>
        <source>Searching...</source>
        <translation>Iskanje ...</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="52"/>
        <source>Show %1 More</source>
        <translation>Pokaži %1 več</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="53"/>
        <source>No videos</source>
        <translation>Nobenega videa</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="54"/>
        <source>No more videos</source>
        <translation>Nobenega videa več</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="src/loadingwidget.cpp" line="71"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/MainWindow.cpp" line="160"/>
        <source>&amp;Stop</source>
        <translation>&amp;Ustavi</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="161"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Ustavi predvajanje in se vrni v iskalni pogled</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="179"/>
        <source>S&amp;kip</source>
        <translation>Pres%koči</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="180"/>
        <source>Skip to the next video</source>
        <translation>Skoči na naslednji video</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="186"/>
        <location filename="src/MainWindow.cpp" line="835"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pavza</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="187"/>
        <location filename="src/MainWindow.cpp" line="836"/>
        <source>Pause playback</source>
        <translation>Premor v predvajanju</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="193"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Celozaslonski način</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="194"/>
        <source>Go full screen</source>
        <translation>Gre v celozaslonski način</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="210"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Skrije predvajalni seznam in orodno vrstico</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="223"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Gre na stran posnetka na YouTube in ustavi predvajanje</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="230"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopira povezavo YouTube trenutnega posnetka v odložišče</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="237"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopira URL trenutnega video pretoka v odložišče</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="244"/>
        <source>Find other video parts hopefully in the right order</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="250"/>
        <source>&amp;Remove</source>
        <translation>Odst&amp;rani</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="251"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Odstrani izbrani video iz predvajalnega seznama</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="257"/>
        <source>Move &amp;Up</source>
        <translation>Premakni &amp;gor</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="258"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Izbrani video premakne mesto više v predvajalnem seznamu</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="264"/>
        <source>Move &amp;Down</source>
        <translation>Premakni &amp;dol</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="265"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Izbrani video premakne mesto niže v predvajalnem seznamu</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="276"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Izbriše zgodovino iskanje. Tega dejanja ni mogoče rayveljaviti.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="281"/>
        <source>&amp;Quit</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="284"/>
        <source>Bye</source>
        <translation>Nasvidenje</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="288"/>
        <source>&amp;Website</source>
        <translation>&amp;Spletno mesto</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="290"/>
        <source>%1 on the Web</source>
        <translation>%1 na spletu</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="296"/>
        <source>Please support the continued development of %1</source>
        <translation>Podprite prosim nadaljni razvoj programa %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="301"/>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="303"/>
        <source>Info about %1</source>
        <translation>Informacije o %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="311"/>
        <source>Search</source>
        <translation>Išči</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="330"/>
        <source>Mute volume</source>
        <translation>Nemo</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="359"/>
        <location filename="src/MainWindow.cpp" line="1179"/>
        <source>&amp;Downloads</source>
        <translation>Pre&amp;nosi</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="360"/>
        <source>Show details about video downloads</source>
        <translation>Pokaže podrobnosti o prenosih posnetkov</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="368"/>
        <source>&amp;Download</source>
        <translation>Pre&amp;nesi</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="369"/>
        <source>Download the current video</source>
        <translation>Prenesi trenutni posnetek</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="381"/>
        <source>Share the current video using %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="393"/>
        <source>&amp;Email</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="394"/>
        <source>Email</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="398"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="403"/>
        <source>&amp;Float on Top</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="408"/>
        <source>&amp;Stop After This Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="445"/>
        <source>&amp;Application</source>
        <translation>&amp;Aplikacija</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="447"/>
        <source>Buy %1...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="458"/>
        <source>&amp;Playback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="472"/>
        <source>&amp;Playlist</source>
        <translation>&amp;Predvajalni seznam</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="479"/>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="490"/>
        <source>&amp;View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="497"/>
        <source>&amp;Share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="509"/>
        <source>&amp;Help</source>
        <translation>P&amp;omoč</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="586"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Pritisnite %1, da povišate glasnost in %2, da jo nižate</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="748"/>
        <location filename="src/MainWindow.cpp" line="754"/>
        <source>Opening %1</source>
        <translation>Odpiranje %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="787"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Ali res želite zapustiti %1 medtem, ko jeaktiven prenos?</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="788"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>V primeru, da zdaj zaprete %1 bo ta prenos prekinjen.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="793"/>
        <source>Close and cancel download</source>
        <translation>Zapri in prekliči prenose</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="794"/>
        <source>Wait for download to finish</source>
        <translation>Počakaj, da konča prenos.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="940"/>
        <source>Leave &amp;Full Screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1283"/>
        <source>%1 version %2 is now available.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1297"/>
        <source>Remind me later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1294"/>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1301"/>
        <source>Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="828"/>
        <source>Error: %1</source>
        <translation>Napaka: %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="169"/>
        <source>P&amp;revious</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="170"/>
        <source>Go back to the previous track</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="209"/>
        <source>&amp;Compact Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="222"/>
        <source>Open the &amp;YouTube Page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="229"/>
        <source>Copy the YouTube &amp;Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="236"/>
        <source>Copy the Video Stream &amp;URL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="243"/>
        <source>Find Video &amp;Parts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="271"/>
        <source>&amp;Clear Recent Searches</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="295"/>
        <source>Make a &amp;Donation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="352"/>
        <source>&amp;Manually Start Playing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="353"/>
        <source>Manually start playing videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="848"/>
        <source>&amp;Play</source>
        <translation>&amp;Predvajaj</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="849"/>
        <source>Resume playback</source>
        <translation>Nadaljuj s predvajanjem</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1055"/>
        <source>Remaining time: %1</source>
        <translation>Preostali čas: %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1113"/>
        <source>Volume at %1%</source>
        <translation>Glasnost %1%</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1119"/>
        <source>Volume is muted</source>
        <translation>Glasnost je utišana</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1122"/>
        <source>Volume is unmuted</source>
        <translation>Glasnost je povrnjena</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1129"/>
        <source>Maximum video definition set to %1</source>
        <translation>Najvišja ločljivost posnetkov je nastavljena na %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1165"/>
        <source>Your privacy is now safe</source>
        <translation>Vaša zasebnost je zdaj varna</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1180"/>
        <source>Downloads complete</source>
        <translation>Prenosi so končani</translation>
    </message>
    <message>
        <location filename="local/mac/macsupport.cpp" line="58"/>
        <source>&amp;Window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="local/mac/macsupport.cpp" line="61"/>
        <source>&amp;Minimize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="src/MediaView.cpp" line="35"/>
        <source>Most relevant</source>
        <translation>Najbolj ustrezni</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="42"/>
        <source>Most recent</source>
        <translation>Najbolj novi</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="49"/>
        <source>Most viewed</source>
        <translation>Najbolj gledani</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="521"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Zdaj lahko prilepite povezavo na YouTube v drugo aplikacijo</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="529"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Zdaj lahko prilepite URL video pretoka v drugo aplikacijo</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="530"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>Povezava bo delovala le za omejen čas.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="629"/>
        <source>This is just the demo version of %1.</source>
        <translation>To je samo demo različica programa %1.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="630"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Dovoli vam testiranje aplikcaije in preverjanje delovanja,</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="660"/>
        <source>Continue</source>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="749"/>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="761"/>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="763"/>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="821"/>
        <source>Sent from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="637"/>
        <source>Get the full version</source>
        <translation>Pridobi celotno različico</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="682"/>
        <source>Downloading %1</source>
        <translation>Prenašanje %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="src/networkaccess.cpp" line="214"/>
        <source>Network error: %1</source>
        <translation>Napak omrežja: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="170"/>
        <source>%1 views</source>
        <translation>%1 predvajanj</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="286"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 od %2 (%3) — %4</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="293"/>
        <source>Preparing</source>
        <translation>Pripravljanje</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="295"/>
        <source>Failed</source>
        <translation>Neuspešno</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="297"/>
        <source>Completed</source>
        <translation>Dokončano</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="299"/>
        <source>Stopped</source>
        <translation>Ustavljeno</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="335"/>
        <source>Stop downloading</source>
        <translation>Ustavi prenos</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="345"/>
        <source>Show in %1</source>
        <translation>Pokaži v %1</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="347"/>
        <source>Open parent folder</source>
        <translation>Odpri nadrejeno mapo</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="356"/>
        <source>Restart downloading</source>
        <translation>Ponovno prenesi</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="177"/>
        <source>Search</source>
        <translation>Išči</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="src/SearchView.cpp" line="79"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Pozdravljeni v &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="46"/>
        <source>Get the full version</source>
        <translation>Pridobi celotno različico</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="93"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation>Vnesite</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="98"/>
        <source>a keyword</source>
        <translation>ključno besedo</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="99"/>
        <source>a channel</source>
        <translation>kanal</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="104"/>
        <source>to start watching videos.</source>
        <translation>in začnite gledati posnetke.</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="128"/>
        <source>Watch</source>
        <translation>Glej</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="146"/>
        <source>Recent keywords</source>
        <translation>Nedavne ključne besede</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="159"/>
        <source>Recent channels</source>
        <translation>Nedavni kanali</translation>
    </message>
    <message>
        <location filename="src/SearchView.h" line="26"/>
        <source>Make yourself comfortable</source>
        <translation>Namestite se udobno</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="src/video.cpp" line="200"/>
        <source>Cannot get video stream for %1</source>
        <translation>Za %1 ni mogoče pridobiti video pretoka</translation>
    </message>
    <message>
        <location filename="src/video.cpp" line="218"/>
        <source>Network error: %1 for %2</source>
        <translation>Napaka omrežja: %1 od %2</translation>
    </message>
</context>
</TS>